@@ -6,11 +6,17 @@ use warnings;
 use Net::Ping;
 use Tie::Scalar;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-sub TIESCALAR { return bless {}, shift;                              }
-sub FETCH     { return $Test::Ping::PROTO;                           }
-sub STORE     { Test::Ping->_ping_object( Net::Ping->new( $_[1] ) ); }
+sub TIESCALAR { return bless {}, shift;    }
+sub FETCH     { return $Test::Ping::PROTO; }
+
+sub STORE {
+    Test::Ping->_ping_object(
+        Net::Ping->new( $_[1] ),
+        $Test::Ping::TIMEOUT
+    );
+}
 
 1;
 
@@ -22,7 +28,7 @@ Test::Ping::Ties::PROTO - Protocol Tie variable to Test::Ping
 
 =head1 VERSON
 
-Version 0.02
+Version 0.03
 
 =head1 DESCRIPTION
 
